parameter names for sensitivity analysis; this can be
a character vector or a comma-separated string (see examples).
var
names of model output variables to include in simulated output;
this could be the name of a compartment or another output derived inside
of the model (e.g. DV or CP or logV, but is specific to what is coded
into mod).
method
parameter sequence generation method.
vary
use each to vary one parameter at a time or grid to vary
all combinations of parameters.
...
passed to method function.
sargs
a named list of arguments passed to sens_each() or
sens_grid() and eventually to mrgsolve::mrgsim().