Plot a lsa object
Usage
# S3 method for class 'lsa'
plot(x, y = NULL, palette = NULL, pal = NULL, ...)Arguments
- x
output from
lsa().- y
not used.
- palette
a discrete color scale object, such as one returned by
ggplot2::scale_color_brewer()orggplot2::scale_color_manual(). WhenNULL(default), a palette is chosen automatically based on the number of parameters.- pal
- ...
not used.